aboutsummaryrefslogtreecommitdiffstats
path: root/libmaple/bkp.c
diff options
context:
space:
mode:
authorMarti Bolivar <mbolivar@leaflabs.com>2011-02-27 11:42:56 -0500
committerMarti Bolivar <mbolivar@leaflabs.com>2011-02-27 11:42:56 -0500
commit4e90248a2e81ec7bd8d3cfa858cef4a045cc1003 (patch)
treefa10544230e6e3e29dcdfc94fd5fc880dce009ba /libmaple/bkp.c
parenta949fe81d069fb3ee727537ba3d5f9f926129d62 (diff)
downloadlibrambutan-4e90248a2e81ec7bd8d3cfa858cef4a045cc1003.tar.gz
librambutan-4e90248a2e81ec7bd8d3cfa858cef4a045cc1003.zip
Cleaned out libmaple.h; this had wide-ranging implications.
Many of the #defines in libmaple.h were board-specific, not MCU-specific. Most of these were only used by code under libmaple/usb/. These were moved into usb_config.h, and are clearly marked as being terrible hacks. I'm going to treat the USB stack as a black box that we'll deal with later. Further, instead of having a variety of #defines like "How many USARTS do I have?", we decide that based on the density of the chip. This is determined by testing for STM32_MEDIUM_DENSITY or STM32_HIGH_DENSITY defines. libmaple currently doesn't support low-density chips, so that suffices. The Makefile will set these automatically based on the MCU. Other offending #defines are ERROR_LED_PORT and ERROR_LED_PIN; these were made optional, but they're set in the Makefile as a hack to keep things working.
Diffstat (limited to 'libmaple/bkp.c')
-rw-r--r--libmaple/bkp.c12
1 files changed, 7 insertions, 5 deletions
diff --git a/libmaple/bkp.c b/libmaple/bkp.c
index ac9aeae..ed107d8 100644
--- a/libmaple/bkp.c
+++ b/libmaple/bkp.c
@@ -69,7 +69,8 @@ void bkp_disable_writes(void) {
/**
* Read a value from given backup data register.
* @param reg Data register to read, from 1 to NR_BKP_REGS (10 on Maple).
*/
uint16 bkp_read(uint8 reg) {
__io uint32* dr = data_register(reg);
@@ -85,7 +86,8 @@ uint16 bkp_read(uint8 reg) {
*
* Write access to backup registers must be enabled.
*
* @param reg Data register to write, from 1 to NR_BKP_REGS (10 on Maple).
* @param val Value to write into the register.
* @see bkp_enable_writes()
*/
@@ -101,16 +103,16 @@ void bkp_write(uint8 reg, uint16 val) {
/*
* Data register memory layout is not contiguous. It's split up from
* 1--NR_LOW_DRS, beginning at BKP_BASE->DR1, through to
- * (NR_LOW_DRS+1)--NR_BKP_REGS, beginning at BKP_BASE->DR10.
+ * (NR_LOW_DRS+1)--BKP_NR_DATA_REGS, beginning at BKP_BASE->DR11.
*/
#define NR_LOW_DRS 10
static inline __io uint32* data_register(uint8 reg) {
- if (reg < 1 || reg > NR_BKP_REGS) {
+ if (reg < 1 || reg > BKP_NR_DATA_REGS) {
return 0;
}
-#if NR_BKP_REGS == NR_LOW_DRS
+#if BKP_NR_DATA_REGS == NR_LOW_DRS
return (uint32*)BKP_BASE + reg;
#else
if (reg <= NR_LOW_DRS) {
@@ -69,7 +69,8 @@ void bkp_disable_writes(void) {
/**
* Read a value from given backup data register.
- * @param reg Data register to read, from 1 to NR_BKP_REGS (10 on Maple).
+ * @param reg Data register to read, from 1 to BKP_NR_DATA_REGS (10 on
+ * medium-density devices, 42 on high-density devices).
*/
uint16 bkp_read(uint8 reg) {
@@ -85,7 +86,8 @@ uint16 bkp_read(uint8 reg) {
* Write access to backup registers must be enabled.
*
- * @param reg Data register to write, from 1 to NR_BKP_REGS (10 on Maple).
+ * @param reg Data register to write, from 1 to BKP_NR_DATA_REGS (10
+ * on medium-density devices, 42 on high-density devices).
* @param val Value to write into the register.
* @see bkp_enable_writes()